/*!
 * \file 
 * \brief Brushless5 Click example
 * 
 * # Description
 * This application with a soft-switching feature for reduced motor noise and EMI.
 *
 * The demo application is composed of two sections :
 * 
 * ## Application Init 
 * Initializes the GPIO driver and configures the PWM peripheral for controlling the speed of the motor.
 * 
 * ## Application Task  
 * Increases and decreases the speed of the motor demonstrating the speed controll.
 * 
 * \author MikroE Team
 *
 */
// ------------------------------------------------------------------- INCLUDES

#include "board.h"
#include "log.h"
#include "brushless5.h"

// ------------------------------------------------------------------ VARIABLES

static brushless5_t brushless5;
static log_t logger;

static pwm_data_t duty_cycle = 100;

// ------------------------------------------------------- ADDITIONAL FUNCTIONS


// ------------------------------------------------------ APPLICATION FUNCTIONS

void application_init ( void )
{
    log_cfg_t log_cfg;
    brushless5_cfg_t cfg;

    //  Logger initialization.

    log_cfg.level = LOG_LEVEL_DEBUG;
    LOG_MAP_USB_UART( log_cfg );
    log_init( &logger, &log_cfg );
    log_info( &logger, "---- Application Init ----" );

    //  Click initialization.

    brushless5_cfg_setup( &cfg );
    BRUSHLESS5_MAP_MIKROBUS( cfg, MIKROBUS_1 );
    brushless5_init( &brushless5, &cfg );

    brushless5_pwm_start( &brushless5 );
}

void application_task ( void )
{
    uint16_t speed;
    
    if ( duty_cycle > brushless5.pwm_period )
    {
        duty_cycle = 100;
    }
    
    for ( speed = 0; speed < brushless5.pwm_period; speed++ )
    {
        brushless5_set_duty_cycle ( &brushless5, speed );
        Delay_10ms( );
    }

    Delay_ms( 1000 );

    for ( speed; speed > 0; speed-- )
    {
        brushless5_set_duty_cycle ( &brushless5, speed );
        Delay_10ms( );
    }

    Delay_ms( 1000 );
}

void main ( void )
{
    application_init( );

    for ( ; ; )
    {
        application_task( );
    }
}


// ------------------------------------------------------------------------ END
